@@ -1,4 +1,3 @@
-from datetime import datetime, timedelta
 from rest_framework_simplejwt.views import TokenObtainPairView
 from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
 
@@ -9,7 +8,6 @@ class TamarinTokenSerializer(TokenObtainPairSerializer):
     def get_token(cls, user):
         token = super().get_token(user)
 
-        token['token-type'] = 'access'
         token['pk'] = user.pk
         token['first-name'] = user.first_name
         token['last-name'] = user.last_name
@@ -17,8 +15,11 @@ class TamarinTokenSerializer(TokenObtainPairSerializer):
         token['email'] = user.email
         token['username'] = user.username
         token['last-login'] = str(user.last_login)
-        token['firebase-token']: getattr(user, 'firebase_token', '')
-
+        token['firebase-token'] = getattr(user, 'firebase_token', '')
+        token['is_active'] = user.is_active
+        token['is_staff'] = user.is_staff
+        token['groups'] = [group.name for group in user.groups.all()]
+        token['permissions'] = [permission.split('.')[1] for permission in user.get_all_permissions()]
         return token
 
 
